@@ -26,30 +26,33 @@ else:
 
 def occli():
 	start = datetime.now()
-	parser = argparse.ArgumentParser(description=f"{green}Unofficial Open Corporates CLI:  {white}OpenCorporates is a website that shares data on corporations under the copyleft Open Database License. This is an unofficial open corporates command line tool developed by {white}Richard Mwewa | {red}https://github.com/{white}rlyonheart{reset}")
-	parser.add_argument("corporation", help=f"{white}company name{reset}")
-	parser.add_argument("-o","--outfile",help=f"{white}write output to a  {green}file{reset}",dest="output", metavar="FILENAME")
-	parser.add_argument("-r","--raw",help=f"{white}return results in {green}raw{white} json{reset}",dest="raw", action="store_true")
-	parser.add_argument("-v","--verbose",help=f"{white}verbosity{reset}",dest="verbose", action="store_true")
+	api = f"https://api.opencorporates.com/v0.4.8/"
+	parser = argparse.ArgumentParser(description=f"{white}Unofficial Open Corporates Command Line Client:  {green}Open Corporates{white} is a website that shares data on corporations under the copyleft Open Database License. This is an unofficial open corporates command line client developed by {white}Richard Mwewa | {green}https://github.com/{white}rlyonheart{reset}")
+	parser.add_argument("-c", "--company",help=f"{white}company name{reset}", dest="companyname", metavar=f"{white}COMPANYNAME{reset}")
+	parser.add_argument("--versions",help=f"{white}get latest Open Corporates API version information({green}can also be run in verbose mode{white}){reset}", dest="versions", action="store_true")
+	parser.add_argument("-o","--output",help=f"{white}write output to a  {green}file{reset}",dest="output", metavar=f"{white}FILENAME{reset}")
+	parser.add_argument("-r","--raw",help=f"{white}return results in raw {green}json{white} format{reset}",dest="raw", action="store_true")
+	parser.add_argument("-v","--verbose",help=f"{white}run occli in {green}verbose{white} mode{reset}",dest="verbose", action="store_true")
 	args = parser.parse_args()
-	
-	mode = ""
-	if args.raw:
-		mode = f"{white}* Started  at {red}{start}{white} (query: {green}{args.corporation}{white}) (raw_mode: {green}active{white})...{reset}"
-	else:
-		mode = f"{white}* Started  at {red}{start}{white} (query: {green}{args.corporation}{white}) (raw_mode: {red}inactive{white})...{reset}"
-	
 	if args.verbose:
-	    print(mode, end="")
 	    logging.basicConfig(format=f"{white}%(message)s{reset}",level=logging.DEBUG)
-	    
+
 	
-	api = f"https://api.opencorporates.com/v0.4.1/companies/search?q={args.corporation}*"
-	    
+	if args.companyname:
+		companies(args,api,start)
+	elif args.versions:
+		versions(args,api)
+	else:
+		print(f"{white}occli: try {green}occli --help{white} to view help message{reset}")
+
+
+def companies(args,api,start):
+	api = api+f"companies/search?q={args.companyname}*"	    
 	interval = 0
-	
+	retries = 0
 	# Main loop
 	while True:
+		retries += 1
 		try:
 			response = requests.get(api).json()
 			for number in range(interval, int(response['results']['per_page'])+1):
@@ -79,53 +82,76 @@ def occli():
 └╼ Open Corporates URL: {red}{response['results']['companies'][number]['company']['opencorporates_url']}{reset}
 """)
 				if args.raw:
-				  print("\n")
-				  pprint(response)
-				  if args.output:
-				  	raw_output(args,response)
-				  break
+				    raw(args,results,response)
+				    break
 				  
 				else:
-				  print(results)
-				  if args.output:
-				  	output(args,results)
-				  	
-				  if number == int(response['results']['per_page'])-1:
-				  	break
+				    print(results)
+				    if args.output:
+				    	output(args,results,response)
+				    	
+				if number == int(response['results']['per_page'])-1:
+					break
 			
 			if args.verbose:
-				exit(f"{white}* Stopped in {red}{datetime.now()-start}{white} seconds.{reset}\n")
+				exit(f"{white}[{green}•{white}] Occli stopped in {red}{datetime.now()-start}{white} seconds.{reset}\n")
 				
 		except IndexError:
 			if args.verbose:
-				exit(f"{white}* Corporation: ({red}{args.corporation}{white}) {red}Not Found{white}.{reset}\n")
+				exit(f"{white}[{red}!{white}] Company: {args.companyname} {red}Not Found{white}.{reset}\n")
 			break
 			
 		except KeyboardInterrupt:
 			if args.verbose:
-				exit(f"\n{white}* Process interrupted ({red}Ctrl{white}+{red}C{white}).{reset}\n")
+				exit(f"\n{white}[{red}x{white}] Occli interrupted ({red}Ctrl{white}+{red}C{white}).{reset}\n")
 			exit()
 			
 		except Exception as e:
 			if args.verbose:
-				print(f"\n{white}* Error ({red}{args.corporation}{white}): {red}{e}{reset}")
-				print(f"{white}* Retrying ({green}{args.corporation}{white})...{reset}")
-
-	
+				print(f"\n{white}[{red}!{white}] Error ({red}{args.companyname}{white}): {red}{e}{reset}")
+				print(f"{white}[{green}*{white}] Retrying::attempt({retries})...{reset}")
+				
 			
-# Save results	
-def output(args,results):
-    with open(args.output, "a") as file:
-        file.write(results)
-        file.close()
+# Save results
+# If the raw flag is included, results will not only be returned in json format but will also be written in json
+def output(args,results,response):
+    if args.raw:
+    	object = json.dumps(response, indent=4)
+    	with open(args.output, "a") as raw:
+    		raw.write(object)
+    		raw.close()
+    		
+    else:
+        with open(args.output, "a") as file:
+        	file.write(results)
+        	file.close()
+        	
+    if args.verbose:
+        print(f"\n{white}[{green}✓{white}] Results written to ./{green}{args.output}{reset}")
+        
+        
+# Return results in raw json format    
+def raw(args,results,response):
+    print("\n")
+    pprint(response)
+    if args.output:
+        output(args,results,response)
+        
+        
+def versions(args,api):
+    api = api+"versions"
+    get_ver = requests.get(api).json()
+    versions = f"""{white}
+Open Corporates API Version Information
+├ current version: {green}{get_ver['results']['versions']['current_version']}{white}
+├─ requested version : {green}{get_ver['results']['versions']['requested_version']}{white}
+├ supported versions: {green}{get_ver['results']['versions']['supported_versions']}{reset}
+"""
+    if args.raw:
+        pprint(get_ver)      
+    else:
+        print(versions)
         
-# Save results as raw json        
-def raw_output(args,response):
-    object = json.dumps(response, indent=4)
-    with open(args.output, "a") as file:
-     	file.write(object)
-     	file.close()
-
  		
 if __name__ == "__main__":
 	occli()
\ No newline at end of file
